@@ -14,24 +14,18 @@ from django.urls import reverse
 
 from spid_cie_oidc.authority.models import (
     FederationDescendant,
-    FederationEntityAssignedProfile,
-    StaffToken,
-    get_first_self_trust_anchor
+    FederationEntityAssignedProfile
 )
 from spid_cie_oidc.authority.settings import MAX_ENTRIES_PAGE
 from spid_cie_oidc.entity.jwtse import (
-    create_jws, unpad_jwt_head,
-    unpad_jwt_payload
+    unpad_jwt_head, unpad_jwt_payload
 )
-from spid_cie_oidc.entity.models import TrustChain
-from spid_cie_oidc.entity.settings import HTTPC_PARAMS
-from spid_cie_oidc.entity.trust_chain_operations import get_or_create_trust_chain
+from spid_cie_oidc.entity.models import get_first_self_trust_anchor
 from spid_cie_oidc.entity.utils import iat_now
 
 from . schemas.fetch_endpoint_request import FetchRequest, FedAPIErrorResponse, FetchResponse
 from . schemas.list_endpoint import ListRequest, ListResponse
 from . schemas.advanced_entity_list_endpoint import AdvancedEntityListRequest, AdvancedEntityListResponse
-from . schemas.resolve_endpoint import ResolveRequest, ResolveResponse
 from . schemas.trust_mark_status_endpoint import TrustMarkRequest, TrustMarkResponse
 
 logger = logging.getLogger(__name__)
@@ -179,87 +173,6 @@ def advanced_entity_listing(request):
     return JsonResponse(res, safe=False)
 
 
-@schema(
-    methods=['GET'],
-    get_request_schema = {
-        "application/x-www-form-urlencoded": ResolveRequest
-    },
-    get_response_schema = {
-            "400": FedAPIErrorResponse,
-            "404": FedAPIErrorResponse,
-            "200": ResolveResponse
-    },
-    tags = ['Federation API']
-)
-def resolve_entity_statement(request, format: str = "jose"):
-    """
-    resolves the final metadata of its descendants
-
-    In this implementation we only returns a preexisting
-    Metadata if it's valid
-    we avoid any possibility to trigger a new Metadata discovery if
-    """
-
-    if not all((request.GET.get("sub", None), request.GET.get("anchor", None))):
-        raise Http404("sub and anchor parameters are REQUIRED.")
-
-    iss = get_first_self_trust_anchor()
-
-    _q = dict(
-        sub=request.GET["sub"],
-        trust_anchor__sub=request.GET["anchor"],
-        is_active=True
-    )
-
-    # gets the cached one
-    entity = TrustChain.objects.filter(**_q).first()
-
-    # only with privileged actors with staff token can triggers a new trust chain
-    staff_token_head = request.headers.get("Authorization", None)
-    if staff_token_head:
-        staff_token = StaffToken.objects.filter(
-            token = staff_token_head
-        ).first()
-        if staff_token.is_valid:
-            try:
-                # a staff token get a fresh trust chain on each call
-                entity = get_or_create_trust_chain(
-                    httpc_params=HTTPC_PARAMS,
-                    required_trust_marks = getattr(
-                        settings, "OIDCFED_REQUIRED_TRUST_MARKS", []
-                    ),
-                    subject=_q["sub"],
-                    trust_anchor=_q["trust_anchor__sub"],
-                    force = True
-                )
-            except Exception as e:
-                logger.error(
-                    f"Failed privileged Trust Chain creation for {_q['sub']}: {e}"
-                )
-
-    if not entity:
-        raise Http404("entity not found.")
-
-    res = {
-        "iss": iss.sub,
-        "sub": request.GET["sub"],
-        # "aud": [],
-        "iat": entity.iat_as_timestamp,
-        "exp": entity.exp_as_timestamp,
-        "trust_marks": entity.trust_marks,
-        "metadata": entity.metadata,
-        "trust_chain": entity.chain
-    }
-
-    if request.GET.get("format") == "json" or format == "json":
-        return JsonResponse(res, safe=False)
-    else:
-        return HttpResponse(
-            create_jws(res, iss.jwks_fed[0]),
-            content_type="application/jose",
-        )
-
-
 @schema(
     methods=['GET'],
     get_request_schema = {
@@ -274,14 +187,14 @@ def resolve_entity_statement(request, format: str = "jose"):
 )
 def trust_mark_status(request):
     failed_data = {"active": False}
-    if request.GET.get("sub", "") and request.GET.get("id", ""):
-        sub = request.GET["sub"]
-        _id = request.GET["id"]
-
-    elif request.GET.get("trust_mark", ""):
+    if request.POST.get("sub", "") and request.POST.get("id", ""):
+        sub = request.POST["sub"]
+        _id = request.POST["id"]
+    
+    elif request.POST.get("trust_mark", ""):
         try:
-            unpad_jwt_head(request.GET["trust_mark"])
-            payload = unpad_jwt_payload(request.GET["trust_mark"])
+            unpad_jwt_head(request.POST["trust_mark"])
+            payload = unpad_jwt_payload(request.POST["trust_mark"])
             sub = payload.get("sub", "")
             _id = payload.get("id", "")
         except Exception:
