@@ -1,8 +1,10 @@
 import json
 import logging
+from typing import Union
 import uuid
 
 from cryptojwt.jwk.jwk import key_from_jwk_dict
+from django.contrib.auth import get_user_model
 from django.db import models
 from django.utils import timezone
 from django.utils.translation import gettext as _
@@ -21,7 +23,7 @@ from spid_cie_oidc.entity.settings import (
     FEDERATION_DEFAULT_EXP
 )
 from spid_cie_oidc.entity.statements import EntityConfiguration
-from spid_cie_oidc.entity.utils import exp_from_now, iat_now
+from spid_cie_oidc.entity.utils import exp_from_now, iat_now, random_token
 from spid_cie_oidc.entity.validators import (
     validate_entity_metadata,
     validate_metadata_algs
@@ -383,3 +385,57 @@ class TrustChain(TimeStampedModel):
         return "{} [{}] [{}]".format(
             self.sub, self.trust_anchor, self.is_valid
         )
+
+
+class StaffToken(TimeStampedModel):
+    """
+        Token provisioned to staffs operators for protected resources
+    """
+
+    user = models.ForeignKey(
+        get_user_model(),
+        on_delete=models.CASCADE,
+        help_text=_("The user responsible of thi token"),
+    )
+    token = models.CharField(
+        max_length=255,
+        blank=False,
+        null=False,
+        default = random_token,
+        help_text=_("it will be generated automatically."),
+    )
+    expire_at = models.DateTimeField(blank=True, null=True)
+    is_active = models.BooleanField(
+        default=True,
+        blank=False,
+        null=False
+    )
+
+    class Meta:
+        verbose_name = "Staff Token"
+        verbose_name_plural = "Staff Tokens"
+
+    @property
+    def is_valid(self):
+        if self.is_active and not self.expire_at:
+            return True
+        elif self.is_active and self.expire_at > timezone.localtime():
+            return True
+        else:
+            return False
+
+    def __str__(self):
+        return f"{self.user} {self.is_active}"
+
+
+def get_first_self_trust_anchor(
+    sub: str = None,
+) -> Union[FederationEntityConfiguration, None]:
+    """
+    get the first available Trust Anchor that represent self
+    as a qualified issuer
+    """
+    lk = dict(metadata__federation_entity__isnull=False, is_active=True)
+    if sub:
+        lk["sub"] = sub
+    return FederationEntityConfiguration.objects.filter(**lk).first()
