@@ -2,7 +2,7 @@ FA_METADATA = {
     "contacts": ["spid.tech@agid.gov.it"],
     "federation_fetch_endpoint": "https://registry.spid.agid.gov.it/oidc/fedapi/",
     "federation_list_endpoint": "https://registry.spid.agid.gov.it/oidc/list/",
-    "federation_status_endpoint": "https://registry.spid.agid.gov.it/oidc/status/",
+    "federation_trust_mark_status_endpoint": "https://registry.spid.agid.gov.it/oidc/status/",
     "federation_resolve_endpoint": "https://registry.spid.agid.gov.it/oidc/resolve/",
     "homepage_uri": "https://spid.agid.gov.it/",
     "organization_name": "Tal dei tali"
