@@ -16,7 +16,7 @@ Including another URLconf
 from django.conf import settings
 from django.urls import path
 
-from .views import entity_configuration
+from .views import entity_configuration, resolve_entity_statement
 
 _PREF = getattr(settings, "OIDC_PREFIX", "")
 
@@ -26,4 +26,5 @@ urlpatterns = [
         entity_configuration,
         name="entity_configuration",
     ),
+    path(f"{_PREF}resolve/", resolve_entity_statement, name="oidcfed_resolve"),
 ]
