@@ -170,13 +170,15 @@ class OpBase:
         head = unpad_jwt_head(client_assertion)
         payload = unpad_jwt_payload(client_assertion)
         _sub = payload.get('sub', None)
-        _aud = payload.get('aud', None)
+        _aud = payload.get('aud', [])
         _op = self.get_issuer()
         _op_eid = _op.sub
         _op_eid_authz_endpoint = [_op.metadata['openid_provider']['authorization_endpoint']]
+
         if isinstance(_aud, str):
             _aud = [_aud]
         _allowed_auds = _aud + _op_eid_authz_endpoint
+
         if _sub != client_id:
             logger.warning(
                 f"Client assertion failed: {_sub} != {client_id}"
@@ -184,13 +186,17 @@ class OpBase:
             # TODO Specialize exceptions
             raise Exception()
 
-        if not _op_eid or _op_eid not in _allowed_auds:
+        if _op_eid:
+            _allowed_auds.append(_op_eid)
+
+        if not _op_eid or self.request.build_absolute_uri() not in _allowed_auds:
             logger.warning(
-                f"Client assertion failed, fake audience: {_sub} != {_op_eid}"
+                "Client assertion failed, fake audience: "
+                f"{self.request.build_absolute_uri()} not in {_allowed_auds}"
             )
             # TODO Specialize exceptions
             raise Exception()
-        
+
         tc = TrustChain.objects.get(sub=client_id, is_active=True)
         jwk = self.find_jwk(head, tc.metadata['openid_relying_party']['jwks']['keys'])
         verify_jws(client_assertion, jwk)
